package backend

import (
	"context"
	"kpt-tmr-group/model"
	"kpt-tmr-group/pkg/logger/zaplog"
	operationPb "kpt-tmr-group/proto/go/backend/operation"
	"sync"

	"go.uber.org/zap"
)

func (s *StoreEntry) GetPermissionsPastureList(ctx context.Context, mobileIds, pastureIds, menuIds []int) *operationPb.SystemUserMenuPermissions {
	systemUserMenuPermissions := &operationPb.SystemUserMenuPermissions{
		PastureList: make([]*operationPb.AddPastureRequest, 0),
		MenuList:    make([]*operationPb.AddMenuRequest, 0),
		MobileList:  make([]*operationPb.AddMobileRequest, 0),
	}
	wg := sync.WaitGroup{}
	wg.Add(3)

	go func() {
		groupPasture := make([]*model.GroupPasture, 0)
		if err := s.DB.Find(&groupPasture, pastureIds).Error; err != nil {
			zaplog.Error("GetPermissionsPastureList", zap.Any("GroupPasture", pastureIds), zap.Any("Err", err))
		}
		systemUserMenuPermissions.PastureList = append(systemUserMenuPermissions.PastureList, model.GroupPastureSlice(groupPasture).ToPermissionsPB()...)
		wg.Done()
	}()

	go func() {
		systemMenu := make([]*model.SystemMenu, 0)
		if err := s.DB.Find(&systemMenu, menuIds).Error; err != nil {
			zaplog.Error("GetPermissionsPastureList", zap.Any("SystemMenu", menuIds), zap.Any("Err", err))
		}
		systemUserMenuPermissions.MenuList = append(systemUserMenuPermissions.MenuList, model.SystemMenuSlice(systemMenu).ToPB()...)
		wg.Done()
	}()

	go func() {
		systemUserMenuPermissions.MobileList = append(systemUserMenuPermissions.MobileList, &operationPb.AddMobileRequest{
			Id:   1,
			Name: "首页",
		}, &operationPb.AddMobileRequest{
			Id:   2,
			Name: "思维效率",
		})
		wg.Done()
	}()

	wg.Wait()
	return systemUserMenuPermissions
}
